User Guide
==========

This section contains guides and documents about ``gb-io`` usage.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

    Installation <install>

.. toctree::
   :maxdepth: 1
   :caption: Resources

   Changelog <changes>
   Contribution Guide <contributing>
   Copyright Notice <copyright>